﻿namespace Sample
{
    using Infragistics.Win;
    using Infragistics.Win.UltraWinSchedule;
    using Infragistics.Win.UltraWinSchedule.DayView;
    using System;
    using System.Drawing;
    using System.Windows.Forms;

    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();                 
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraDayView1.DrawFilter = new AppointmentDrawFilter();
            this.ultraCalendarInfo1.Owners.UnassignedOwner.Visible = false;
            this.ultraCalendarInfo1.Owners.Add("Welby", "Dr. Marcus Welby");
            this.ultraCalendarInfo1.Owners.Add("Kimble", "Dr. Richard Kimble");
            this.ultraCalendarInfo1.Owners.Add("Quincy", "Dr. Quincy");
            this.ultraCalendarInfo1.Owners.Add("Spencer", "Dr. Luke Spencer");
            this.ultraDayView1.GroupingStyle = DayViewGroupingStyle.OwnerWithinDate;
            this.ultraDayView1.TimeSlotInterval = TimeSlotInterval.ThirtyMinutes;

            var startDate1 = new DateTime(2017, 10, 26, 9, 0, 0);
            var endDate1 = new DateTime(2017, 10, 26, 10, 0, 0);
            var appointment1 = new Appointment(startDate1, endDate1);
            appointment1.Owner = this.ultraCalendarInfo1.Owners[1];
            appointment1.Subject = "Scrum Meeting";
            appointment1.Description = "Some test description 1";


            var startDate2 = new DateTime(2017, 10, 26, 11, 0, 0);
            var endDate2 = new DateTime(2017, 10, 26, 12, 0, 0);
            var appointment2 = new Appointment(startDate2, endDate2);
            appointment2.Owner = this.ultraCalendarInfo1.Owners[2];
            appointment2.Subject = "Meeting";
            appointment2.Description = "Some test description 2";

            this.ultraCalendarInfo1.Appointments.Add(appointment1);
            this.ultraCalendarInfo1.Appointments.Add(appointment2);

            this.ultraDayView1.CalendarLook.ViewStyle = ViewStyle.VisualStudio2005;
        }
    }


    public class AppointmentDrawFilter : IUIElementDrawFilter
    {
        private const int Offset = 3;        

        #region DrawFilter
        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
                var appointmentElement = drawParams.Element as AppointmentUIElement;
                if (appointmentElement != null)
                {
                var editorWithTextElement = appointmentElement.GetDescendant(typeof(EditorWithTextUIElement)) as EditorWithTextUIElement;
                if (editorWithTextElement != null)
                {
                    var point1_x = editorWithTextElement.Rect.Left - Offset;
                    var point1_y = editorWithTextElement.Rect.Top - Offset;
                    var point2_y = editorWithTextElement.Rect.Y + editorWithTextElement.Rect.Height;

                    var point1 = new Point(point1_x, point1_y);                    
                    var point2 = new Point(point1_x,  point2_y);

                    var pen = new Pen(Color.Red, 1);
                    drawParams.Graphics.DrawLine(pen, point1, point2);
                    pen.Dispose();

                    return true;
                }
            }

            return false;
        }
        #endregion DrawFilter

        #region GetPhasesToFilter
        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if (drawParams.Element is AppointmentUIElement)
                return DrawPhase.BeforeDrawBorders;

            return DrawPhase.None;
        }
        #endregion //GetPhasesToFilter
    }
}
